@@ -13,7 +13,7 @@ mod window;
 
 use std::sync::OnceLock;
 
-use gettextrs::{gettext, LocaleCategory};
+use gettextrs::{LocaleCategory, gettext};
 use glib::ExitCode;
 use gtk::{gio, glib};
 use tokio::runtime::Runtime;
@@ -23,10 +23,14 @@ use self::config::{GETTEXT_PACKAGE, LOCALEDIR, RESOURCES_FILE};
 
 fn runtime() -> &'static Runtime {
     static RUNTIME: OnceLock<Runtime> = OnceLock::new();
-    RUNTIME.get_or_init(|| Runtime::new().expect("Setting up tokio runtime needs to succeed."))
+    RUNTIME.get_or_init(|| {
+        tokio::runtime::Builder::new_multi_thread()
+            .enable_all()
+            .build()
+            .expect("Setting up tokio runtime needs to succeed.")
+    })
 }
 
-const GHOST_SCRIPT_BINARY_NAME: &str = "gs";
 const ZIP_BINARY_NAME: &str = "zip";
 
 fn main() -> ExitCode {
